@@ -90,6 +90,16 @@ class Schema(object):
         # Never use this.descriptor inside this class (!!!)
         return self.__next_descriptor
 
+    @property
+    def missing_values(self):
+        """Schema's missing values
+
+        # Returns
+            str[]: missing values
+
+        """
+        return self.__current_descriptor.get('missingValues', [])
+
     @property
     def primary_key(self):
         """Schema's primary keys
